pub enum MachExceptionHandler {
Tag(ExceptionTag, LabelOrOffset),
Default(LabelOrOffset),
Context(ExceptionContextLoc),
}Expand description
An item in the exception-handler list for a callsite, with label references. Items are interpreted in left-to-right order and the first match wins.
Variants
Tag(ExceptionTag, LabelOrOffset)
A specific tag (in the current dynamic context) should be handled by the code at the given offset.
Default(LabelOrOffset)
All exceptions should be handled by the code at the given offset.
Context(ExceptionContextLoc)
The dynamic context for interpreting tags is updated to the value stored in the given machine location (in this frame’s context).