ControlFlowGraph

Struct ControlFlowGraph 

pub struct ControlFlowGraph { /* private fields */ }
The Control Flow Graph maintains a mapping of blocks to their predecessors and successors where predecessors are basic blocks and successors are basic blocks.

Implementations

Source

impl ControlFlowGraph

pub fn new() -> Self

Allocate a new blank control flow graph.

pub fn clear(&mut self)

Clear all data structures in this control flow graph.

pub fn with_function(func: &Function) -> Self

Allocate and compute the control flow graph for func.

pub fn compute(&mut self, func: &Function)

Compute the control flow graph of func.

This will clear and overwrite any information already stored in this data structure.

pub fn recompute_block(&mut self, func: &Function, block: Block)

Recompute the control flow graph of block.

This is for use after modifying instructions within a specific block. It recomputes all edges from block while leaving edges to block intact. Its functionality a subset of that of the more expensive compute, and should be used when we know we don’t need to recompute the CFG from scratch, but rather that our changes have been restricted to specific blocks.

pub fn pred_iter(&self, block: Block) -> PredIter<'_>

Get an iterator over the CFG predecessors to block.

pub fn succ_iter(&self, block: Block) -> SuccIter<'_>

Get an iterator over the CFG successors to block.

pub fn blocks(&self) -> impl ExactSizeIterator<Item = Block> + '_

Get an iterator over all blocks this control-flow graph has storage for, in block order.

This may include blocks that are not in the function’s layout (e.g. a block that was created but never inserted, or has since been removed); such blocks have no predecessors or successors in the graph.

pub fn num_blocks(&self) -> usize

Get the number of blocks this control-flow graph has storage for.

This equals func.dfg.num_blocks() for the function the CFG was computed from, and is an upper bound on the block indices appearing in the graph.

pub fn is_valid(&self) -> bool

Check if the CFG is in a valid state.

Note that this doesn’t perform any kind of validity checks. It simply checks if the compute() method has been called since the last clear(). It does not check that the CFG is consistent with the function.