Struct cranelift_codegen::ir::constant::ConstantPoolEntry [−][src]
pub struct ConstantPoolEntry { /* fields omitted */ }Expand description
Inner type for storing data and offset together in the constant pool. The offset is optional
because it must be set relative to the function code size (i.e. constants are emitted after the
function body); because the function is not yet compiled when constants are inserted,
set_offset must be called once a constant’s offset
from the beginning of the function is known (see
relaxation in relaxation.rs).
Implementations
Assign a new offset to the constant at this entry.