Enum cranelift_codegen::ir::dfg::ValueDef [−][src]
Where did a value come from?
Variants
Value is the n’th result of an instruction.
Value is the n’th parameter to a block.
Implementations
Unwrap the instruction where the value was defined, or panic.
Unwrap the block there the parameter is defined, or panic.
Get the program point where the value was defined.