Struct cranelift_codegen::ir::entities::Block [−][src]
pub struct Block(_);
An opaque reference to a basic block in a
Function.
You can get a Block using
FunctionBuilder::create_block
While the order is stable, it is arbitrary and does not necessarily resemble the layout order.
Implementations
impl Block[src]
impl Block[src]pub fn with_number(n: u32) -> Option<Self>[src]
pub fn with_number(n: u32) -> Option<Self>[src]Create a new block reference from its number. This corresponds to the blockNN representation.
This method is for use by the parser.