Struct cranelift_codegen::ir::entities::StackSlot [−][src]
pub struct StackSlot(_);
An opaque reference to a stack slot.
Stack slots represent an address on the call stack.
StackSlots can be created with
FunctionBuilder::create_stackslot.
StackSlots are most often used with
stack_addr,
stack_load, and
stack_store.
While the order is stable, it is arbitrary and does not necessarily resemble the stack order.
Implementations
impl StackSlot[src]
impl StackSlot[src]pub fn with_number(n: u32) -> Option<Self>[src]
pub fn with_number(n: u32) -> Option<Self>[src]Create a new stack slot reference from its number.
This method is for use by the parser.