[−][src]Struct cranelift_codegen::ir::entities::Value
An opaque reference to an SSA value.
You can get a constant Value from the following
InstBuilder instructions:
iconstfor integer constantsf32constfor 32-bit float constantsf64constfor 64-bit float constantsbconstfor boolean constantsvconstfor vector constantsnullfor null reference constants
Any InstBuilder instruction that has an output will also return a Value.
Methods
impl Value
pub fn from_u32(x: u32) -> Self
Return the underlying index value as a u32.
pub fn as_u32(self) -> u32
Return the underlying index value as a u32.
impl Value[src]
pub fn with_number(n: u32) -> Option<Self>[src]
Create a value from its number representation.
This is the number in the vNN notation.
This method is for use by the parser.