TrapCode

Enum TrapCode 

pub enum TrapCode {
Show 14 variants StackOverflow, HeapOutOfBounds, HeapMisaligned, TableOutOfBounds, IndirectCallToNull, BadSignature, IntegerOverflow, IntegerDivisionByZero, BadConversionToInteger, UnreachableCodeReached, Interrupt, User(u16), NullReference, NullI31Ref,
}
A trap code describing the reason for a trap.

All trap instructions have an explicit trap code.

Variants



StackOverflow

The current stack space was exhausted.



HeapOutOfBounds

A heap_addr instruction detected an out-of-bounds error.

Note that not all out-of-bounds heap accesses are reported this way; some are detected by a segmentation fault on the heap unmapped or offset-guard pages.



HeapMisaligned

A wasm atomic operation was presented with a not-naturally-aligned linear-memory address.



TableOutOfBounds

A table_addr instruction detected an out-of-bounds error.



IndirectCallToNull

Indirect call to a null table entry.



BadSignature

Signature mismatch on indirect call.



IntegerOverflow

An integer arithmetic operation caused an overflow.



IntegerDivisionByZero

An integer division by zero.



BadConversionToInteger

Failed float-to-int conversion.



UnreachableCodeReached

Code that was supposed to have been unreachable was reached.



Interrupt

Execution has potentially run too long and may be interrupted.



User(u16)

A user-defined trap code.



NullReference

A null reference was encountered which was required to be non-null.



NullI31Ref

A null i31ref was encountered which was required to be non-null.

Implementations

Source

impl TrapCode

pub const fn non_user_traps() -> &'static [TrapCode]

Returns a slice of all traps except TrapCode::User traps