Enum cranelift_codegen::ir::ValueLoc [−][src]
Value location.
Variants
This value has not been assigned to a location yet.
Reg(RegUnit)Value is assigned to a register.
Stack(StackSlot)Value is assigned to a stack slot.
Implementations
Is this an assigned location? (That is, not Unassigned).
Get the register unit of this location, or panic.
Get the stack slot of this location, or panic.