Struct cranelift_codegen::ir::immediates::Offset32 [−][src]
pub struct Offset32(_);
32-bit signed immediate offset.
This is used to encode an immediate offset for load/store instructions. All supported ISAs have
a maximum load/store offset that fits in an i32.
Methods
impl Offset32[src]
impl Offset32Trait Implementations
impl Copy for Offset32[src]
impl Copy for Offset32impl Clone for Offset32[src]
impl Clone for Offset32fn clone(&self) -> Offset32[src]
fn clone(&self) -> Offset32Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl PartialEq for Offset32[src]
impl PartialEq for Offset32fn eq(&self, other: &Offset32) -> bool[src]
fn eq(&self, other: &Offset32) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Offset32) -> bool[src]
fn ne(&self, other: &Offset32) -> boolThis method tests for !=.
impl Eq for Offset32[src]
impl Eq for Offset32impl Debug for Offset32[src]
impl Debug for Offset32fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for Offset32[src]
impl Hash for Offset32fn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Into<i32> for Offset32[src]
impl Into<i32> for Offset32impl Into<i64> for Offset32[src]
impl Into<i64> for Offset32impl From<i32> for Offset32[src]
impl From<i32> for Offset32impl Display for Offset32[src]
impl Display for Offset32fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl FromStr for Offset32[src]
impl FromStr for Offset32