Struct cranelift_codegen::ir::immediates::Uimm32
source · pub struct Uimm32(_);Expand description
A 32-bit unsigned integer immediate operand.
This is used to represent sizes of memory objects.
pub struct Uimm32(_);A 32-bit unsigned integer immediate operand.
This is used to represent sizes of memory objects.