Struct cranelift_codegen::ir::jumptable::JumpTableData [−][src]
pub struct JumpTableData { /* fields omitted */ }Expand description
Contents of a jump table.
All jump tables use 0-based indexing and are densely populated.
Implementations
impl JumpTableData[src]
impl JumpTableData[src]pub fn with_capacity(capacity: usize) -> Self[src]
pub fn with_capacity(capacity: usize) -> Self[src]Create a new empty jump table with the specified capacity.
pub fn push_entry(&mut self, dest: Block)[src]
pub fn push_entry(&mut self, dest: Block)[src]Append a table entry.
pub fn branches_to(&self, block: Block) -> bool[src]
pub fn branches_to(&self, block: Block) -> bool[src]Checks if any of the entries branch to block.
pub fn as_mut_slice(&mut self) -> &mut [Block]ⓘ[src]
pub fn as_mut_slice(&mut self) -> &mut [Block]ⓘ[src]Access the whole table as a mutable slice.