pub struct AliasRegionData {
pub user_id: u32,
pub description: Cow<'static, str>,
}Expand description
Data describing an alias region.
Fields
user_id: u32A unique, user-defined identifier for this alias region.
Alias regions are deduplicated based on this identifier.
This deduplication happens during inlining, for example, when a callee’s alias regions are merged with the caller’s. Therefore, when inlining is enabled this identifier should be globally unique across the whole compilation. When inlining is disabled, it is sufficient to be unique within the context of a single function.
description: Cow<'static, str>Description of this alias region, e.g. “vmctx”, “funcref table”,
“global 42”, or “gc struct LinkedList field tail”.
This only exists for printing in the CLIF text format.