pub struct AliasRegionSet { /* private fields */ }Expand description
A deduplicated set of alias regions.
Deduplication is based on user_id; the description string is not
considered.
Implementations
Sourceimpl AliasRegionSet
impl AliasRegionSet
Sourcepub fn insert(&mut self, data: AliasRegionData) -> AliasRegion
pub fn insert(&mut self, data: AliasRegionData) -> AliasRegion
Insert a new alias region into this set.
Returns an existing AliasRegion if one with the same user_id
already exists.
Sourcepub fn push(&mut self, data: AliasRegionData) -> AliasRegion
pub fn push(&mut self, data: AliasRegionData) -> AliasRegion
Push a new alias region, bypassing deduplication.
This is used by the CLIF text parser to faithfully represent the
source text. The verifier will then check for duplicate user_ids.
Sourcepub fn contains(&self, user_id: u32) -> bool
pub fn contains(&self, user_id: u32) -> bool
Returns true if this set already contains a region with the given
user_id.
Sourcepub fn is_valid(&self, ar: AliasRegion) -> bool
pub fn is_valid(&self, ar: AliasRegion) -> bool
Returns true if the given alias region reference is valid.
Sourcepub fn iter(&self) -> impl Iterator<Item = (AliasRegion, &AliasRegionData)>
pub fn iter(&self) -> impl Iterator<Item = (AliasRegion, &AliasRegionData)>
Iterate over all alias regions and their data.