pub struct MachMemFlags { /* private fields */ }Expand description
Backend memory-operation flags.
These are the bit-packed flags that backends operate on directly.
Unlike ir::MemFlagsData, this does not carry alias-region metadata.
Implementations
Sourceimpl MachMemFlags
impl MachMemFlags
Sourcepub const fn trusted() -> Self
pub const fn trusted() -> Self
Create a set of flags representing an access from a “trusted” address.
Sourcepub const fn endianness(self, native_endianness: Endianness) -> Endianness
pub const fn endianness(self, native_endianness: Endianness) -> Endianness
Return endianness of the memory access.
Sourcepub const fn explicit_endianness(self) -> Option<Endianness>
pub const fn explicit_endianness(self) -> Option<Endianness>
Return endianness of the memory access, if explicitly specified.
Sourcepub const fn with_endianness(self, endianness: Endianness) -> Self
pub const fn with_endianness(self, endianness: Endianness) -> Self
Set endianness of the memory access, returning new flags.
Sourcepub const fn with_notrap(self) -> Self
pub const fn with_notrap(self) -> Self
Set these flags to indicate this access does not trap.
Sourcepub const fn with_can_move(self) -> Self
pub const fn with_can_move(self) -> Self
Set the can_move flag, returning new flags.
Sourcepub const fn with_aligned(self) -> Self
pub const fn with_aligned(self) -> Self
Set the aligned flag, returning new flags.
Sourcepub const fn with_readonly(self) -> Self
pub const fn with_readonly(self) -> Self
Set the readonly flag, returning new flags.
Sourcepub const fn trap_code(self) -> Option<TrapCode>
pub const fn trap_code(self) -> Option<TrapCode>
Get the trap code to report if this memory access traps.
Sourcepub const fn with_trap_code(self, code: Option<TrapCode>) -> Self
pub const fn with_trap_code(self, code: Option<TrapCode>) -> Self
Configures these flags with the specified trap code code.