pub struct MaybeRelSourceLoc(/* private fields */);Expand description
A source location that is either a RelSourceLoc or SourceLoc.
This is used to represent a source location in the MachBuffer
that is initially relative to some base and is later relocated. We
do this to permit better code caching during incremental
compilation: the MachBuffer records the first SourceLoc it is
given as a base, and if the same function IR is later compiled but
with a different starting SourceLoc, we can reuse the cached
compilation result and just relocate (offset) the SourceLocs.
This relocation is an in-place update pass, so we want a “union”
type, essentially, but we don’t want to pay the overhead of a true
enum (8 bytes rather than 4 in a large array), so we bitpack
this representation.
Implementations
Sourceimpl MaybeRelSourceLoc
impl MaybeRelSourceLoc
Sourcepub fn rel(loc: RelSourceLoc) -> Self
pub fn rel(loc: RelSourceLoc) -> Self
Create a relative SourceLoc.
Sourcepub fn as_rel(&self) -> RelSourceLoc
pub fn as_rel(&self) -> RelSourceLoc