Struct cranelift_codegen::ir::TableData [−][src]
pub struct TableData {
pub base_gv: GlobalValue,
pub min_size: Imm64,
pub bound_gv: GlobalValue,
pub element_size: Imm64,
}Information about a table declaration.
Fields
base_gv: GlobalValue
Global value giving the address of the start of the table.
min_size: Imm64
Guaranteed minimum table size in elements. Table accesses before min_size don't need
bounds checking.
bound_gv: GlobalValue
Global value giving the current bound of the table, in elements.
element_size: Imm64
The size of a table element, in bytes.