VecALUOp

Enum VecALUOp 

pub enum VecALUOp {
Show 41 variants Sqadd, Uqadd, Sqsub, Uqsub, Cmeq, Cmge, Cmgt, Cmhs, Cmhi, Fcmeq, Fcmgt, Fcmge, And, Bic, Orr, Eor, Umaxp, Add, Sub, Mul, Sshl, Ushl, Umin, Smin, Umax, Smax, Urhadd, Fadd, Fsub, Fdiv, Fmax, Fmin, Fmul, Addp, Zip1, Zip2, Sqrdmulh, Uzp1, Uzp2, Trn1, Trn2,
}
Available on crate feature arm64 only.
Internal type VecALUOp: defined at src/isa/aarch64/inst.isle line 1485.

Variants



Sqadd



Uqadd



Sqsub



Uqsub



Cmeq



Cmge



Cmgt



Cmhs



Cmhi



Fcmeq



Fcmgt



Fcmge



And



Bic



Orr



Eor



Umaxp



Add



Sub



Mul



Sshl



Ushl



Umin



Smin



Umax



Smax



Urhadd



Fadd



Fsub



Fdiv



Fmax



Fmin



Fmul



Addp



Zip1



Zip2



Sqrdmulh



Uzp1



Uzp2



Trn1



Trn2