tmp2_reg

Function tmp2_reg 

pub fn tmp2_reg() -> Reg
Available on crate feature arm64 only.
Get a reference to the second temp register. We need this in some edge cases where we need both the spilltmp and another temporary.

We use x17 (aka IP1), the other “interprocedural”/linker-veneer scratch reg that is free to use otherwise.