pub struct CallInfo {
pub dest: ExternalName,
pub uses: SmallVec<[CallArgPair; 8]>,
pub defs: SmallVec<[CallRetPair; 8]>,
pub clobbers: PRegSet,
pub caller_callconv: CallConv,
pub callee_callconv: CallConv,
pub callee_pop_size: u32,
}Expand description
Additional information for (direct) Call instructions, left out of line to lower the size of the Inst enum.
Fields
dest: ExternalNameCall destination.
uses: SmallVec<[CallArgPair; 8]>Arguments to the call instruction.
defs: SmallVec<[CallRetPair; 8]>Return values from the call instruction.
clobbers: PRegSetClobbers register set.
caller_callconv: CallConvCaller calling convention.
callee_callconv: CallConvCallee calling convention.
callee_pop_size: u32The number of bytes that the callee will pop from the stack for the
caller, if any. (Used for popping stack arguments with the tail
calling convention.)