Enum cranelift_codegen::isa::unwind::systemv::RegisterMappingError [−][src]
pub enum RegisterMappingError {
MissingBank,
UnsupportedArchitecture,
UnsupportedRegisterBank(&'static str),
}Expand description
Enumerate the errors possible in mapping Cranelift registers to their DWARF equivalent.
Variants
UnsupportedRegisterBank(&'static str)Tuple Fields of UnsupportedRegisterBank
0: &'static strTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.