pub struct XmmMemAligned64(/* private fields */);Available on crate feature
x86 only.Expand description
A newtype wrapper around RegMem for general-purpose registers.
Implementations
Sourceimpl XmmMemAligned64
impl XmmMemAligned64
Sourcepub const SIZE_BITS: u32 = 64
pub const SIZE_BITS: u32 = 64
The bit width of the value this operand holds. This is
a type-level distinction only; the underlying RegMem
does not record the width.
Sourcepub fn new(rm: RegMem) -> Option<Self>
pub fn new(rm: RegMem) -> Option<Self>
Construct a RegMem newtype from the given RegMem, or return
None if the RegMem is not a valid instance of this RegMem
newtype.
Sourcepub fn unwrap_new(rm: RegMem) -> Self
pub fn unwrap_new(rm: RegMem) -> Self
Like Self::new(rm).unwrap() but with better panic messages
in case of failure.
Sourcepub fn to_reg_mem(self) -> RegMem
pub fn to_reg_mem(self) -> RegMem
Convert this newtype into its underlying RegMem.