Enum cranelift_codegen::isa::x64::encoding::rex::LegacyPrefixes [−][src]
pub enum LegacyPrefixes {
None,
_66,
_F0,
_66F0,
_F2,
_F3,
_66F3,
}Expand description
We may need to include one or more legacy prefix bytes before the REX prefix. This enum covers only the small set of possibilities that we actually need.
Variants
No prefix bytes.
Operand Size Override – here, denoting “16-bit operation”.
The Lock prefix.
Operand size override and Lock.
REPNE, but no specific meaning here – is just an opcode extension.
REP/REPE, but no specific meaning here – is just an opcode extension.
Operand size override and same effect as F3.