Enum cranelift_codegen::machinst::abi_impl::ABIArg[][src]

pub enum ABIArg {
    Slots {
        slots: Vec<ABIArgSlot>,
        purpose: ArgumentPurpose,
    },
    StructArg {
        offset: i64,
        size: u64,
        purpose: ArgumentPurpose,
    },
}
An ABIArg is composed of one or more parts. This allows for a CLIF-level Value to be passed with its parts in more than one location at the ABI level. For example, a 128-bit integer may be passed in two 64-bit registers, or even a 64-bit register and a 64-bit stack slot, on a 64-bit machine. The number of “parts” should correspond to the number of registers used to store this type according to the machine backend.

As an invariant, the purpose for every part must match. As a further invariant, a StructArg part cannot appear with any other part.

Variants

Slots

Storage slots (registers or stack locations) for each part of the argument value. The number of slots must equal the number of register parts used to store a value of this type.

Show fields

Fields of Slots

slots: Vec<ABIArgSlot>

Slots, one per register part.

purpose: ArgumentPurpose

Purpose of this arg.

StructArg

Structure argument. We reserve stack space for it, but the CLIF-level semantics are a little weird: the value passed to the call instruction, and received in the corresponding block param, is a pointer. On the caller side, we memcpy the data from the passed-in pointer to the stack area; on the callee side, we compute a pointer to this stack area and provide that as the argument’s value.

Show fields

Fields of StructArg

offset: i64

Offset of this arg relative to base of stack args.

size: u64

Size of this arg on the stack.

purpose: ArgumentPurpose

Purpose of this arg.

Implementations

Create an ABIArg from one register.

Create an ABIArg from one stack slot.