Enum cranelift_codegen::machinst::abi_impl::ArgsOrRets [−][src]
pub enum ArgsOrRets {
Args,
Rets,
}Expand description
Are we computing information about arguments or return values? Much of the handling is factored out into common routines; this enum allows us to distinguish which case we’re handling.
Variants
Arguments.
Return values.