Enum cranelift_codegen::machinst::abi_impl::StackAMode [−][src]
Abstract location for a machine-specific ABI impl to translate into the appropriate addressing mode.
Variants
Offset from the frame pointer, possibly making use of a specific type for a scaled indexing operation.
Offset from the nominal stack pointer, possibly making use of a specific type for a scaled indexing operation.
Offset from the real stack pointer, possibly making use of a specific type for a scaled indexing operation.
Implementations