Enum cranelift_codegen::machinst::blockorder::LoweredBlock [−][src]
pub enum LoweredBlock {
Orig {
block: Block,
},
OrigAndEdge {
block: Block,
edge_inst: Inst,
succ: Block,
},
EdgeAndOrig {
pred: Block,
edge_inst: Inst,
block: Block,
},
Edge {
pred: Block,
edge_inst: Inst,
succ: Block,
},
}Expand description
The origin of a block in the lowered block-order: either an original CLIF block, or an inserted edge-block, or a combination of the two if an edge is non-critical.
Variants
Block in original CLIF, with no merged edge-blocks.
Show fields
Fields of Orig
block: BlockOriginal CLIF block.
Block in the original CLIF, plus edge-block to one succ (which is the one successor of the original block).
Show fields
Block in the original CLIF, preceded by edge-block from one pred (which is the one pred of the original block).
Show fields
Split critical edge between two CLIF blocks. This lowered block does not
correspond to any original CLIF blocks; it only serves as an insertion
point for work to happen on the transition from pred to succ.
Show fields
Implementations
The associated original (CLIF) block included in this lowered block, if any.