Struct cranelift_codegen::machinst::buffer::MachBufferFinalized [−][src]
pub struct MachBufferFinalized {
pub data: SmallVec<[u8; 1024]>,
pub unwind_info: SmallVec<[(CodeOffset, UnwindInst); 8]>,
// some fields omitted
}Expand description
A MachBuffer once emission is completed: holds generated code and records,
without fixups. This allows the type to be independent of the backend.
Fields
data: SmallVec<[u8; 1024]>The buffer contents, as raw bytes.
unwind_info: SmallVec<[(CodeOffset, UnwindInst); 8]>Any unwind info at a given location.
Implementations
Get a list of source location mapping tuples in sorted-by-start-offset order.
Get the total required size for the code.