Struct cranelift_codegen::machinst::buffer::MachLabel [−][src]
pub struct MachLabel(_);
A label refers to some offset in a MachBuffer. It may not be resolved at
the point at which it is used by emitted code; the buffer records “fixups”
for references to the label, and will come back and patch the code
appropriately when the label’s location is eventually known.
Implementations
Get a label for a block. (The first N MachLabels are always reseved for the N blocks in the vcode.)