Struct cranelift_codegen::machinst::buffer::MachStackMap [−][src]
pub struct MachStackMap {
pub offset: CodeOffset,
pub offset_end: CodeOffset,
pub stack_map: StackMap,
}Expand description
Record of stack map metadata: stack offsets containing references.
Fields
offset: CodeOffsetThe code offset at which this stack map applies.
offset_end: CodeOffsetThe code offset just past the “end” of the instruction: that is, the offset of the first byte of the following instruction, or equivalently, the start offset plus the instruction length.
stack_map: StackMapThe stack map itself.