Enum cranelift_codegen::machinst::MachTerminator [−][src]
pub enum MachTerminator<'a> {
None,
Ret,
Uncond(MachLabel),
Cond(MachLabel, MachLabel),
Indirect(&'a [MachLabel]),
}Expand description
Describes a block terminator (not call) in the vcode, when its branches have not yet been finalized (so a branch may have two targets).
Variants
Not a terminator.
A return instruction.
Uncond(MachLabel)An unconditional branch to another block.
A conditional branch to one of two other blocks.
An indirect branch with known possible targets.
Implementations