Enum cranelift_codegen::machinst::lower::RelocDistance [−][src]
pub enum RelocDistance {
Near,
Far,
}Expand description
Notion of “relocation distance”. This gives an estimate of how far away a symbol will be from a reference.
Variants
Target of relocation is “nearby”. The threshold for this is fuzzy but should be interpreted
as approximately “within the compiled output of one module”; e.g., within AArch64’s +/-
128MB offset. If unsure, use Far instead.
Target of relocation could be anywhere in the address space.