Struct cranelift_codegen::machinst::lower::NonRegInput [−][src]
A representation of all of the ways in which a value is available, aside from as a direct register.
-
An instruction, if it would be allowed to occur at the current location instead (see LowerCtx::get_input_as_source_or_const() for more details).
-
A constant, if the value is known to be a constant.
Fields
inst: Option<(Inst, usize)>An instruction produces this value (as the given output), and its computation (and side-effect if applicable) could occur at the current instruction’s location instead.
If this instruction’s operation is merged into the current instruction, the backend must call LowerCtx::sink_inst().
constant: Option<u64>The value is a known constant.