[−][src]Trait cranelift_codegen::machinst::vcode::VCodeInst
VCodeInst wraps all requirements for a MachInst to be in VCode: it must be
a MachInst and it must be able to emit itself at least to a SizeCodeSink.
VCodeInst wraps all requirements for a MachInst to be in VCode: it must be
a MachInst and it must be able to emit itself at least to a SizeCodeSink.
impl<I: MachInst + MachInstEmit<MachSection> + MachInstEmit<MachSectionSize>> VCodeInst for I[src]