pub struct CompiledCodeStencil(/* private fields */);Expand description
Result of compiling a FunctionStencil, before applying FunctionParameters onto it.
Only used internally, in a transient manner, for the incremental compilation cache.
Implementations
Sourceimpl CompiledCodeStencil
impl CompiledCodeStencil
Sourcepub fn apply_params(self, params: &FunctionParameters) -> CompiledCode
pub fn apply_params(self, params: &FunctionParameters) -> CompiledCode
Apply function parameters to finalize a stencil into its final form.