pub struct MachCallSiteItem<'a> {
pub ret_addr: CodeOffset,
pub frame_offset: Option<u32>,
pub exception_handlers: &'a [MachExceptionHandler],
}Expand description
A view onto a call site record resulting from a compilation, returned during iteration.
Fields
ret_addr: CodeOffsetThe offset of the call’s return address, relative to the start of the buffer.
frame_offset: Option<u32>The offset from the FP at this callsite down to the SP when the call occurs, if known.
See MachCallSite::frame_offset for more.
exception_handlers: &'a [MachExceptionHandler]Exception handlers at this site.