pub struct MachSrcLoc {
pub start: CodeOffset,
pub end: CodeOffset,
pub loc: MaybeRelSourceLoc,
}Expand description
A source-location mapping resulting from a compilation.
Fields
start: CodeOffsetThe start of the region of code corresponding to a source location. This is relative to the start of the function, not to the start of the section.
end: CodeOffsetThe end of the region of code corresponding to a source location. This is relative to the start of the function, not to the start of the section.
loc: MaybeRelSourceLocThe source location.