take_current

Function take_current 

pub fn take_current() -> PassTimes
Available on crate feature timing only.
Take the current accumulated pass timings and reset the timings for the current thread.

Only applies when DefaultProfiler is used.

Panics

Panics when any pass timing token is currently active.