pub enum RelocTarget {
ExternalName(ExternalName),
Label(LabelOrOffset),
}Expand description
A Relocation target
Variants
ExternalName(ExternalName)
Points to an ExternalName outside the current function.
Label(LabelOrOffset)
Points to a MachLabel inside this function. This is different from an internal fixup/label reference in that both the relocation and the label will be emitted and are only resolved at link time.
There is no reason to prefer this over internal fixups unless the ABI requires it.
Implementations
Sourceimpl RelocTarget
impl RelocTarget
Sourcepub fn display<'a>(&'a self, params: Option<&'a FunctionParameters>) -> String
pub fn display<'a>(&'a self, params: Option<&'a FunctionParameters>) -> String
Returns a display for the current RelocTarget, with extra context to prettify the output.