Enum cranelift_codegen::ir::dfg::ValueDef [−][src]
Where did a value come from?
Variants
Value is the n’th result of an instruction.
Value is the n’th parameter to a block.
Implementations
impl ValueDef[src]
impl ValueDef[src]pub fn unwrap_inst(&self) -> Inst[src]
pub fn unwrap_inst(&self) -> Inst[src]Unwrap the instruction where the value was defined, or panic.
pub fn unwrap_block(&self) -> Block[src]
pub fn unwrap_block(&self) -> Block[src]Unwrap the block there the parameter is defined, or panic.
pub fn pp(self) -> ExpandedProgramPoint[src]
pub fn pp(self) -> ExpandedProgramPoint[src]Get the program point where the value was defined.