Enum cranelift_codegen::ir::entities::AnyEntity [−][src]
pub enum AnyEntity {
}Expand description
An opaque reference to any of the entities defined in this module that can appear in CLIF IR.
Variants
Function
The whole function.
Block(Block)
Tuple Fields
0: Blocka basic block.
Inst(Inst)
Tuple Fields
0: InstAn instruction.
Value(Value)
Tuple Fields
0: ValueAn SSA value.
StackSlot(StackSlot)
Tuple Fields
0: StackSlotA stack slot.
GlobalValue(GlobalValue)
Tuple Fields
0: GlobalValueA Global value.
JumpTable(JumpTable)
Tuple Fields
0: JumpTableA jump table.
Constant(Constant)
Tuple Fields
0: ConstantA constant.
FuncRef(FuncRef)
Tuple Fields
0: FuncRefAn external function.
SigRef(SigRef)
Tuple Fields
0: SigRefA function call signature.
Heap(Heap)
Tuple Fields
0: HeapA heap.
Table(Table)
Tuple Fields
0: TableA table.
StackLimit
A function’s stack limit