Enum cranelift_codegen::ir::entities::AnyEntity [−][src]
pub enum AnyEntity {
}Expand description
An opaque reference to any of the entities defined in this module that can appear in CLIF IR.
Variants
The whole function.
a basic block.
Tuple Fields of Block
0: BlockAn instruction.
Tuple Fields of Inst
0: InstAn SSA value.
Tuple Fields of Value
0: ValueA stack slot.
Tuple Fields of StackSlot
0: StackSlotA Global value.
Tuple Fields of GlobalValue
0: GlobalValueA jump table.
Tuple Fields of JumpTable
0: JumpTableA constant.
Tuple Fields of Constant
0: ConstantAn external function.
Tuple Fields of FuncRef
0: FuncRefA function call signature.
Tuple Fields of SigRef
0: SigRefA heap.
Tuple Fields of Heap
0: HeapA table.
Tuple Fields of Table
0: TableA function’s stack limit