Opcode

Enum Opcode 

#[repr(u8)]
pub enum Opcode {
Show 171 variants Jump = 1, Brif = 2, BrTable = 3, Debugtrap = 4, Trap = 5, Trapz = 6, Trapnz = 7, Return = 8, Call = 9, CallIndirect = 10, ReturnCall = 11, ReturnCallIndirect = 12, FuncAddr = 13, TryCall = 14, TryCallIndirect = 15, Splat = 16, Swizzle = 17, X86Pshufb = 18, Insertlane = 19, Extractlane = 20, Smin = 21, Umin = 22, Smax = 23, Umax = 24, AvgRound = 25, UaddSat = 26, SaddSat = 27, UsubSat = 28, SsubSat = 29, Load = 30, Store = 31, Uload8 = 32, Sload8 = 33, Istore8 = 34, Uload16 = 35, Sload16 = 36, Istore16 = 37, Uload32 = 38, Sload32 = 39, Istore32 = 40, StackSwitch = 41, Uload8x8 = 42, Sload8x8 = 43, Uload16x4 = 44, Sload16x4 = 45, Uload32x2 = 46, Sload32x2 = 47, StackLoad = 48, StackStore = 49, StackAddr = 50, DynamicStackLoad = 51, DynamicStackStore = 52, DynamicStackAddr = 53, GlobalValue = 54, SymbolValue = 55, TlsValue = 56, GetPinnedReg = 57, SetPinnedReg = 58, GetFramePointer = 59, GetStackPointer = 60, GetReturnAddress = 61, GetExceptionHandlerAddress = 62, Iconst = 63, F16const = 64, F32const = 65, F64const = 66, F128const = 67, Vconst = 68, Shuffle = 69, Nop = 70, Select = 71, SelectSpectreGuard = 72, Bitselect = 73, Blendv = 74, VanyTrue = 75, VallTrue = 76, VhighBits = 77, Icmp = 78, Iadd = 79, Isub = 80, Ineg = 81, Iabs = 82, Imul = 83, Umulhi = 84, Smulhi = 85, SqmulRoundSat = 86, X86Pmulhrsw = 87, Udiv = 88, Sdiv = 89, Urem = 90, Srem = 91, SaddOverflowCin = 92, UaddOverflowCin = 93, UaddOverflow = 94, SaddOverflow = 95, UsubOverflow = 96, SsubOverflow = 97, UmulOverflow = 98, SmulOverflow = 99, UaddOverflowTrap = 100, SsubOverflowBin = 101, UsubOverflowBin = 102, Band = 103, Bor = 104, Bxor = 105, Bnot = 106, BandNot = 107, BorNot = 108, BxorNot = 109, Rotl = 110, Rotr = 111, Ishl = 112, Ushr = 113, Sshr = 114, Bitrev = 115, Clz = 116, Cls = 117, Ctz = 118, Bswap = 119, Popcnt = 120, Fcmp = 121, Fadd = 122, Fsub = 123, Fmul = 124, Fdiv = 125, Sqrt = 126, Fma = 127, Fneg = 128, Fabs = 129, Fcopysign = 130, Fmin = 131, Fmax = 132, Ceil = 133, Floor = 134, Trunc = 135, Nearest = 136, Bitcast = 137, ScalarToVector = 138, Bmask = 139, Ireduce = 140, Snarrow = 141, Unarrow = 142, Uunarrow = 143, SwidenLow = 144, SwidenHigh = 145, UwidenLow = 146, UwidenHigh = 147, IaddPairwise = 148, X86Pmaddubsw = 149, Uextend = 150, Sextend = 151, Fpromote = 152, Fdemote = 153, Fvdemote = 154, FvpromoteLow = 155, FcvtToUint = 156, FcvtToSint = 157, FcvtToUintSat = 158, FcvtToSintSat = 159, X86Cvtt2dq = 160, FcvtFromUint = 161, FcvtFromSint = 162, Isplit = 163, Iconcat = 164, AtomicRmw = 165, AtomicCas = 166, AtomicLoad = 167, AtomicStore = 168, Fence = 169, ExtractVector = 170, SequencePoint = 171,
}
An instruction opcode.

All instructions from all supported ISAs are present.

Variants



Jump = 1

jump block_call. (Jump)



Brif = 2

brif c, block_then, block_else. (Brif) Type inferred from c.



BrTable = 3

br_table x, JT. (BranchTable)



Debugtrap = 4

debugtrap. (NullAry)



Trap = 5

trap code. (Trap)



Trapz = 6

trapz c, code. (CondTrap) Type inferred from c.



Trapnz = 7

trapnz c, code. (CondTrap) Type inferred from c.



Return = 8

return rvals. (MultiAry)



Call = 9

rvals = call FN, args. (Call)



CallIndirect = 10

rvals = call_indirect SIG, callee, args. (CallIndirect) Type inferred from callee.



ReturnCall = 11

return_call FN, args. (Call)



ReturnCallIndirect = 12

return_call_indirect SIG, callee, args. (CallIndirect) Type inferred from callee.



FuncAddr = 13

addr = func_addr FN. (FuncAddr)



TryCall = 14

try_call callee, args, ET. (TryCall)



TryCallIndirect = 15

try_call_indirect callee, args, ET. (TryCallIndirect) Type inferred from callee.



Splat = 16

a = splat x. (Unary)



Swizzle = 17

a = swizzle x, y. (Binary)



X86Pshufb = 18

a = x86_pshufb x, y. (Binary)



Insertlane = 19

a = insertlane x, y, Idx. (TernaryImm8) Type inferred from x.



Extractlane = 20

a = extractlane x, Idx. (BinaryImm8) Type inferred from x.



Smin = 21

a = smin x, y. (Binary) Type inferred from x.



Umin = 22

a = umin x, y. (Binary) Type inferred from x.



Smax = 23

a = smax x, y. (Binary) Type inferred from x.



Umax = 24

a = umax x, y. (Binary) Type inferred from x.



AvgRound = 25

a = avg_round x, y. (Binary) Type inferred from x.



UaddSat = 26

a = uadd_sat x, y. (Binary) Type inferred from x.



SaddSat = 27

a = sadd_sat x, y. (Binary) Type inferred from x.



UsubSat = 28

a = usub_sat x, y. (Binary) Type inferred from x.



SsubSat = 29

a = ssub_sat x, y. (Binary) Type inferred from x.



Load = 30

a = load MemFlags, p, Offset. (Load)



Store = 31

store MemFlags, x, p, Offset. (Store) Type inferred from x.



Uload8 = 32

a = uload8 MemFlags, p, Offset. (Load)



Sload8 = 33

a = sload8 MemFlags, p, Offset. (Load)



Istore8 = 34

istore8 MemFlags, x, p, Offset. (Store) Type inferred from x.



Uload16 = 35

a = uload16 MemFlags, p, Offset. (Load)



Sload16 = 36

a = sload16 MemFlags, p, Offset. (Load)



Istore16 = 37

istore16 MemFlags, x, p, Offset. (Store) Type inferred from x.



Uload32 = 38

a = uload32 MemFlags, p, Offset. (Load) Type inferred from p.



Sload32 = 39

a = sload32 MemFlags, p, Offset. (Load) Type inferred from p.



Istore32 = 40

istore32 MemFlags, x, p, Offset. (Store) Type inferred from x.



StackSwitch = 41

out_payload0 = stack_switch store_context_ptr, load_context_ptr, in_payload0. (Ternary) Type inferred from load_context_ptr.



Uload8x8 = 42

a = uload8x8 MemFlags, p, Offset. (Load) Type inferred from p.



Sload8x8 = 43

a = sload8x8 MemFlags, p, Offset. (Load) Type inferred from p.



Uload16x4 = 44

a = uload16x4 MemFlags, p, Offset. (Load) Type inferred from p.



Sload16x4 = 45

a = sload16x4 MemFlags, p, Offset. (Load) Type inferred from p.



Uload32x2 = 46

a = uload32x2 MemFlags, p, Offset. (Load) Type inferred from p.



Sload32x2 = 47

a = sload32x2 MemFlags, p, Offset. (Load) Type inferred from p.



StackLoad = 48

a = stack_load SS, Offset. (StackLoad)



StackStore = 49

stack_store x, SS, Offset. (StackStore) Type inferred from x.



StackAddr = 50

addr = stack_addr SS, Offset. (StackLoad)



DynamicStackLoad = 51

a = dynamic_stack_load DSS. (DynamicStackLoad)



DynamicStackStore = 52

dynamic_stack_store x, DSS. (DynamicStackStore) Type inferred from x.



DynamicStackAddr = 53

addr = dynamic_stack_addr DSS. (DynamicStackLoad)



GlobalValue = 54

a = global_value GV. (UnaryGlobalValue)



SymbolValue = 55

a = symbol_value GV. (UnaryGlobalValue)



TlsValue = 56

a = tls_value GV. (UnaryGlobalValue)



GetPinnedReg = 57

addr = get_pinned_reg. (NullAry)



SetPinnedReg = 58

set_pinned_reg addr. (Unary) Type inferred from addr.



GetFramePointer = 59

addr = get_frame_pointer. (NullAry)



GetStackPointer = 60

addr = get_stack_pointer. (NullAry)



GetReturnAddress = 61

addr = get_return_address. (NullAry)



GetExceptionHandlerAddress = 62

addr = get_exception_handler_address block, index. (ExceptionHandlerAddress)



Iconst = 63

a = iconst N. (UnaryImm)



F16const = 64

a = f16const N. (UnaryIeee16)



F32const = 65

a = f32const N. (UnaryIeee32)



F64const = 66

a = f64const N. (UnaryIeee64)



F128const = 67

a = f128const N. (UnaryConst)



Vconst = 68

a = vconst N. (UnaryConst)



Shuffle = 69

a = shuffle a, b, mask. (Shuffle)



Nop = 70

nop. (NullAry)



Select = 71

a = select c, x, y. (Ternary) Type inferred from x.



SelectSpectreGuard = 72

a = select_spectre_guard c, x, y. (Ternary) Type inferred from x.



Bitselect = 73

a = bitselect c, x, y. (Ternary) Type inferred from x.



Blendv = 74

a = blendv c, x, y. (Ternary) Type inferred from x.



VanyTrue = 75

s = vany_true a. (Unary) Type inferred from a.



VallTrue = 76

s = vall_true a. (Unary) Type inferred from a.



VhighBits = 77

x = vhigh_bits a. (Unary)



Icmp = 78

a = icmp Cond, x, y. (IntCompare) Type inferred from x.



Iadd = 79

a = iadd x, y. (Binary) Type inferred from x.



Isub = 80

a = isub x, y. (Binary) Type inferred from x.



Ineg = 81

a = ineg x. (Unary) Type inferred from x.



Iabs = 82

a = iabs x. (Unary) Type inferred from x.



Imul = 83

a = imul x, y. (Binary) Type inferred from x.



Umulhi = 84

a = umulhi x, y. (Binary) Type inferred from x.



Smulhi = 85

a = smulhi x, y. (Binary) Type inferred from x.



SqmulRoundSat = 86

a = sqmul_round_sat x, y. (Binary) Type inferred from x.



X86Pmulhrsw = 87

a = x86_pmulhrsw x, y. (Binary) Type inferred from x.



Udiv = 88

a = udiv x, y. (Binary) Type inferred from x.



Sdiv = 89

a = sdiv x, y. (Binary) Type inferred from x.



Urem = 90

a = urem x, y. (Binary) Type inferred from x.



Srem = 91

a = srem x, y. (Binary) Type inferred from x.



SaddOverflowCin = 92

a, c_out = sadd_overflow_cin x, y, c_in. (Ternary) Type inferred from y.



UaddOverflowCin = 93

a, c_out = uadd_overflow_cin x, y, c_in. (Ternary) Type inferred from y.



UaddOverflow = 94

a, of = uadd_overflow x, y. (Binary) Type inferred from x.



SaddOverflow = 95

a, of = sadd_overflow x, y. (Binary) Type inferred from x.



UsubOverflow = 96

a, of = usub_overflow x, y. (Binary) Type inferred from x.



SsubOverflow = 97

a, of = ssub_overflow x, y. (Binary) Type inferred from x.



UmulOverflow = 98

a, of = umul_overflow x, y. (Binary) Type inferred from x.



SmulOverflow = 99

a, of = smul_overflow x, y. (Binary) Type inferred from x.



UaddOverflowTrap = 100

a = uadd_overflow_trap x, y, code. (IntAddTrap) Type inferred from x.



SsubOverflowBin = 101

a, b_out = ssub_overflow_bin x, y, b_in. (Ternary) Type inferred from y.



UsubOverflowBin = 102

a, b_out = usub_overflow_bin x, y, b_in. (Ternary) Type inferred from y.



Band = 103

a = band x, y. (Binary) Type inferred from x.



Bor = 104

a = bor x, y. (Binary) Type inferred from x.



Bxor = 105

a = bxor x, y. (Binary) Type inferred from x.



Bnot = 106

a = bnot x. (Unary) Type inferred from x.



BandNot = 107

a = band_not x, y. (Binary) Type inferred from x.



BorNot = 108

a = bor_not x, y. (Binary) Type inferred from x.



BxorNot = 109

a = bxor_not x, y. (Binary) Type inferred from x.



Rotl = 110

a = rotl x, y. (Binary) Type inferred from x.



Rotr = 111

a = rotr x, y. (Binary) Type inferred from x.



Ishl = 112

a = ishl x, y. (Binary) Type inferred from x.



Ushr = 113

a = ushr x, y. (Binary) Type inferred from x.



Sshr = 114

a = sshr x, y. (Binary) Type inferred from x.



Bitrev = 115

a = bitrev x. (Unary) Type inferred from x.



Clz = 116

a = clz x. (Unary) Type inferred from x.



Cls = 117

a = cls x. (Unary) Type inferred from x.



Ctz = 118

a = ctz x. (Unary) Type inferred from x.



Bswap = 119

a = bswap x. (Unary) Type inferred from x.



Popcnt = 120

a = popcnt x. (Unary) Type inferred from x.



Fcmp = 121

a = fcmp Cond, x, y. (FloatCompare) Type inferred from x.



Fadd = 122

a = fadd x, y. (Binary) Type inferred from x.



Fsub = 123

a = fsub x, y. (Binary) Type inferred from x.



Fmul = 124

a = fmul x, y. (Binary) Type inferred from x.



Fdiv = 125

a = fdiv x, y. (Binary) Type inferred from x.



Sqrt = 126

a = sqrt x. (Unary) Type inferred from x.



Fma = 127

a = fma x, y, z. (Ternary) Type inferred from y.



Fneg = 128

a = fneg x. (Unary) Type inferred from x.



Fabs = 129

a = fabs x. (Unary) Type inferred from x.



Fcopysign = 130

a = fcopysign x, y. (Binary) Type inferred from x.



Fmin = 131

a = fmin x, y. (Binary) Type inferred from x.



Fmax = 132

a = fmax x, y. (Binary) Type inferred from x.



Ceil = 133

a = ceil x. (Unary) Type inferred from x.



Floor = 134

a = floor x. (Unary) Type inferred from x.



Trunc = 135

a = trunc x. (Unary) Type inferred from x.



Nearest = 136

a = nearest x. (Unary) Type inferred from x.



Bitcast = 137

a = bitcast MemFlags, x. (LoadNoOffset)



ScalarToVector = 138

a = scalar_to_vector s. (Unary)



Bmask = 139

a = bmask x. (Unary)



Ireduce = 140

a = ireduce x. (Unary)



Snarrow = 141

a = snarrow x, y. (Binary) Type inferred from x.



Unarrow = 142

a = unarrow x, y. (Binary) Type inferred from x.



Uunarrow = 143

a = uunarrow x, y. (Binary) Type inferred from x.



SwidenLow = 144

a = swiden_low x. (Unary) Type inferred from x.



SwidenHigh = 145

a = swiden_high x. (Unary) Type inferred from x.



UwidenLow = 146

a = uwiden_low x. (Unary) Type inferred from x.



UwidenHigh = 147

a = uwiden_high x. (Unary) Type inferred from x.



IaddPairwise = 148

a = iadd_pairwise x, y. (Binary) Type inferred from x.



X86Pmaddubsw = 149

a = x86_pmaddubsw x, y. (Binary)



Uextend = 150

a = uextend x. (Unary)



Sextend = 151

a = sextend x. (Unary)



Fpromote = 152

a = fpromote x. (Unary)



Fdemote = 153

a = fdemote x. (Unary)



Fvdemote = 154

a = fvdemote x. (Unary)



FvpromoteLow = 155

x = fvpromote_low a. (Unary)



FcvtToUint = 156

a = fcvt_to_uint x. (Unary)



FcvtToSint = 157

a = fcvt_to_sint x. (Unary)



FcvtToUintSat = 158

a = fcvt_to_uint_sat x. (Unary)



FcvtToSintSat = 159

a = fcvt_to_sint_sat x. (Unary)



X86Cvtt2dq = 160

a = x86_cvtt2dq x. (Unary)



FcvtFromUint = 161

a = fcvt_from_uint x. (Unary)



FcvtFromSint = 162

a = fcvt_from_sint x. (Unary)



Isplit = 163

lo, hi = isplit x. (Unary) Type inferred from x.



Iconcat = 164

a = iconcat lo, hi. (Binary) Type inferred from lo.



AtomicRmw = 165

a = atomic_rmw MemFlags, AtomicRmwOp, p, x. (AtomicRmw)



AtomicCas = 166

a = atomic_cas MemFlags, p, e, x. (AtomicCas) Type inferred from x.



AtomicLoad = 167

a = atomic_load MemFlags, p. (LoadNoOffset)



AtomicStore = 168

atomic_store MemFlags, x, p. (StoreNoOffset) Type inferred from x.



Fence = 169

fence. (NullAry)



ExtractVector = 170

a = extract_vector x, y. (BinaryImm8) Type inferred from x.



SequencePoint = 171

sequence_point. (NullAry)

Implementations

Source

impl Opcode

pub fn is_terminator(self) -> bool

True for instructions that terminate the block

pub fn is_branch(self) -> bool

True for all branch or jump instructions.

pub fn is_call(self) -> bool

Is this a call instruction?

pub fn is_return(self) -> bool

Is this a return instruction?

pub fn can_load(self) -> bool

Can this instruction read from memory?

pub fn can_store(self) -> bool

Can this instruction write to memory?

pub fn can_trap(self) -> bool

Can this instruction cause a trap?

pub fn other_side_effects(self) -> bool

Does this instruction have other side effects besides can_* flags?

pub fn side_effects_idempotent(self) -> bool

Despite having side effects, is this instruction okay to GVN?

pub fn all() -> &'static [Opcode]

All cranelift opcodes.

Source

impl Opcode

pub fn format(self) -> InstructionFormat

Get the instruction format for this opcode.

pub fn constraints(self) -> OpcodeConstraints

Get the constraint descriptor for this opcode. Panic if this is called on NotAnOpcode.

pub fn is_safepoint(self) -> bool

Is this instruction a GC safepoint?

Safepoints are all kinds of calls, except for tail calls.