CallConv

Enum CallConv 

pub enum CallConv {
    Fast,
    Cold,
    Tail,
    SystemV,
    WindowsFastcall,
    AppleAarch64,
    Probestack,
    WasmtimeSystemV,
    Winch,
}
Calling convention identifiers.

Variants



Fast

Best performance, not ABI-stable.



Cold

Smallest caller code size, not ABI-stable.



Tail

Supports tail calls, not ABI-stable.



SystemV

System V-style convention used on many platforms.



WindowsFastcall

Windows “fastcall” convention, also used for x64 and ARM.



AppleAarch64

Mac aarch64 calling convention, which is a tweaked aarch64 ABI.



Probestack

Specialized convention for the probestack function.



WasmtimeSystemV

Wasmtime equivalent of SystemV, not ABI-stable.

FIXME: remove this when Wasmtime uses the “tail” calling convention for all wasm functions.



Winch

The winch calling convention, not ABI-stable.

The main difference to WasmtimeSystemV is that the winch calling convention defines no callee-save registers, and restricts the number of return registers to one integer, and one floating point.

Implementations

Source

impl CallConv

pub fn triple_default(triple: &Triple) -> Self

Return the default calling convention for the given target triple.

pub fn for_libcall(flags: &Flags, default_call_conv: CallConv) -> Self

Returns the calling convention used for libcalls according to the current flags.

pub fn supports_tail_calls(&self) -> bool

Does this calling convention support tail calls?

pub fn extends_windows_fastcall(self) -> bool

Is the calling convention extending the Windows Fastcall ABI?

pub fn extends_apple_aarch64(self) -> bool

Is the calling convention extending the Apple aarch64 ABI?