Data structures describing the registers in an ISA.

Structs

Temporary object that holds enough information to print a register unit.
The register units in a target ISA are divided into disjoint register banks. Each bank covers a contiguous range of register units.
Data about a register class.
A small reference to a register class.
Information about the registers in an ISA.

Constants

Guaranteed maximum number of top-level register classes with pressure tracking in any ISA.

Functions

Test of two registers overlap.

Type Definitions

A register class reference.
A bit mask indexed by register classes.
Register units are the smallest units of register allocation.
A bit mask indexed by register units.