Enum cranelift_codegen::machinst::abi_impl::ABIArg [−][src]
A location for an argument or return value.
Variants
In a real register (or set of registers).
Fields of Reg
regs: ValueRegs<RealReg>Register(s) that hold this arg.
ty: TypeValue type of this arg.
extension: ArgumentExtensionShould this arg be zero- or sign-extended?
purpose: ArgumentPurposePurpose of this arg.
Arguments only: on stack, at given offset from SP at entry.
Fields of Stack
offset: i64Offset of this arg relative to the base of stack args.
ty: TypeValue type of this arg.
extension: ArgumentExtensionShould this arg be zero- or sign-extended?
purpose: ArgumentPurposePurpose of this arg.
Structure argument. We reserve stack space for it, but the CLIF-level semantics are a little weird: the value passed to the call instruction, and received in the corresponding block param, is a pointer. On the caller side, we memcpy the data from the passed-in pointer to the stack area; on the callee side, we compute a pointer to this stack area and provide that as the argument’s value.
Fields of StructArg
offset: i64Offset of this arg relative to base of stack args.
size: u64Size of this arg on the stack.
purpose: ArgumentPurposePurpose of this arg.