Struct cranelift_codegen::machinst::abi_impl::ABICallerImpl[][src]

pub struct ABICallerImpl<M: ABIMachineSpec> { /* fields omitted */ }
ABI object for a callsite.

Implementations

Create a callsite ABI object for a call directly to the specified function.

Create a callsite ABI object for a call to a function pointer with the given signature.