[][src]Trait cranelift_codegen::machinst::MachInstEmitState

pub trait MachInstEmitState<I: MachInst>: Default + Clone + Debug {
    fn new(abi: &dyn ABIBody<I = I>) -> Self;

    fn pre_safepoint(&mut self, _stackmap: Stackmap) { ... }
}

A trait describing the emission state carried between MachInsts when emitting a function body.

Required methods

fn new(abi: &dyn ABIBody<I = I>) -> Self

Create a new emission state given the ABI object.

Loading content...

Provided methods

fn pre_safepoint(&mut self, _stackmap: Stackmap)

Update the emission state before emitting an instruction that is a safepoint.

Loading content...

Implementors

Loading content...