Function cranelift_codegen::timing::take_current [−][src]
pub fn take_current() -> PassTimesExpand description
Take the current accumulated pass timings and reset the timings for the current thread.
pub fn take_current() -> PassTimesTake the current accumulated pass timings and reset the timings for the current thread.