pub fn take_current() -> PassTimesAvailable on crate feature
timing only.Expand description
Take the current accumulated pass timings and reset the timings for the current thread.
Only applies when DefaultProfiler is used.
Panics
Panics when any pass timing token is currently active.